internal

package
v0.1.0-alpha007 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 4, 2025 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// ErrDockerHostNotSet is returned when the Docker host is not set in the Docker context.
	ErrDockerHostNotSet = errors.New("docker host not set in Docker context")

	// ErrDockerContextNotFound is returned when the Docker context is not found.
	ErrDockerContextNotFound = errors.New("docker context not found")
)

Functions

func List

func List(metaRoot string) ([]string, error)

List returns the list of contexts available in the Docker configuration.

Types

type Context

type Context struct {
	// contains filtered or unexported fields
}

Context represents a Docker context

func Inspect

func Inspect(ctxName string, metaRoot string) (Context, error)

Inspect returns the description of the given context. It returns an error if the context is not found or if the docker endpoint is not set.

Jump to